from breame.data.american_terms_constants import AMERICAN_ENGLISH_ONLY_TERMS
from breame.data.british_terms_constants import BRITISH_ENGLISH_ONLY_TERMS
from breame.utils import process_word


def is_british_english_term(word: str) -> bool:
    """
    Returns True if the word is a British English specific term, False otherwise.
    """
    word = process_word(word)
    return word in BRITISH_ENGLISH_ONLY_TERMS


def is_american_english_term(word: str) -> bool:
    """
    Returns True if the word is an American English specific term, False otherwise.
    """
    word = process_word(word)
    return word in AMERICAN_ENGLISH_ONLY_TERMS


def get_british_term_definition(word: str) -> str:
    """
    Returns the British English definition of the word.
    """
    word = process_word(word)
    return BRITISH_ENGLISH_ONLY_TERMS[word]


def get_american_term_definition(word: str) -> str:
    """
    Returns the American English definition of the word.
    """
    word = process_word(word)
    return AMERICAN_ENGLISH_ONLY_TERMS[word]



from breame.data.meaning_constants import DIFFERENT_MEANINGS_US_UK_COMMON
from breame.utils import process_word


def different_meanings_exist(word: str) -> bool:
    """
    Checks if the word has multiple meanings American, British, or Common English.
    Returns True if the word has multiple meanings, False otherwise.
    """
    word = process_word(word)
    if word in DIFFERENT_MEANINGS_US_UK_COMMON:
        return True
    return False


def get_meaning_definitions(word: str) -> dict:
    """
    Retrieves the multiple meaning definitions of a word. In some combination of
    American, British, and Common English. Returns a dictionary of the multiple meanings
    if they exist, otherwise returns an empty dictionary.
    """
    word = process_word(word)

    if word in DIFFERENT_MEANINGS_US_UK_COMMON:
        return DIFFERENT_MEANINGS_US_UK_COMMON[word]
    return {}



from breame.data.spelling_constants import (
    AMERICAN_ENGLISH_SPELLINGS,
    BRITISH_ENGLISH_SPELLINGS,
)
from breame.utils import process_word


def get_british_spelling(word: str) -> str:
    """
    Get the British spelling of an American English word.
    """
    word = process_word(word)
    if word not in AMERICAN_ENGLISH_SPELLINGS:
        return word
    return AMERICAN_ENGLISH_SPELLINGS[word]


def get_american_spelling(word: str) -> str:
    """
    Get the American spelling of a British English word.
    """
    word = process_word(word)
    if word not in BRITISH_ENGLISH_SPELLINGS:
        return word
    return BRITISH_ENGLISH_SPELLINGS[word]


def american_spelling_exists(word: str) -> bool:
    """
    Check if an American English spelling exists.
    """
    word = process_word(word)
    return word in AMERICAN_ENGLISH_SPELLINGS


def british_spelling_exists(word: str) -> bool:
    """
    Check if a British English spelling exists.
    """
    word = process_word(word)
    return word in BRITISH_ENGLISH_SPELLINGS



from distutils.core import setup

from setuptools import find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


setup(
    name="breame",
    packages=find_packages(
        exclude=[
            "*.tests",
            "*.tests.*",
            "tests.*",
            "tests",
            "examples",
            "docs",
            "out",
            "dist",
            "media",
            "test",
        ]
    ),
    version="0.1.0",
    license="Apache-2.0",
    description="Breame is a lightweight Python package with a number of utility tools to aid in the detection of words that have dual spellings and meanings in British and American English.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Charles Pierse",
    author_email="charlespierse@gmail.com",
    url="https://github.com/cdpierse/breame",
    keywords=[
        "text processing",
        "natural language proessing",
        "utility library",
        "spelling",
        "search engine"
    ],
    classifiers=[
        "Development Status :: 3 - Alpha",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.8",
    ],
)
